@@ -2,9 +2,9 @@
 import { Platform } from 'react-native'
 const cheerio = require('react-native-cheerio')
 import {NativeModules} from 'react-native';
-module.exports = NativeModules.DemoLibrary;
+module.exports = NativeModules.DemoModuleExample;
 
-import DemoLibrary from './DemoLibrary';
+import DemoModule from './DemoModuleExample';
 
 
 var DemoLibrary = {
@@ -29,7 +29,7 @@ var DemoLibrary = {
 
       }).then(response => response.text())
         .then((response) => {
-          console.log('local version ' , DemoLibrary.getPackageName())
+          console.log('local version ' , DemoModule.getPackageName())
           const $ = cheerio.load(response)
           var version = $('<div/>').html(response).contents().find('div[itemprop=\"softwareVersion\"]').text().trim()
           console.log('version ', version)
